
/*
 * DISCLAIMER:
 *
 *   THIS SOFTWARE IS SUPPLIED AS-IS BY THE JOHNS HOPKINS UNIVERSITY/APPLIED PHYSICS
 *   LABORATORY (JHU/APL).
 *
 *   WITH RESPECT TO THE INFORMATION, CODE AND/OR EXECUTABLES PROVIDED HEREIN,
 *   JHU/APL MAKES NO WARRANTIES OF ANY KIND, EITHER EXPRESSED OR IMPLIED,
 *   INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 *   FITNESS FOR A PARTICULAR PURPOSE. IN ADDITION, IN NO EVENT SHALL JHU/APL
 *   BE HELD LIABLE FOR ANY DAMAGES WHATSOEVER INCLUDING DIRECT, INDIRECT, INCIDENTAL,
 *   CONSEQUENTIAL, LOSS OF BUSINESS PROFITS OR SPECIAL DAMAGES, EVEN IF
 *   JHU/APL HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*/

#ifndef __BC635_H__
#define __BC635_H__

/* Timing modes for card */

#define BC635_MODE_TIMECODE             0x00
#define BC635_MODE_FREERUN              0x01
#define BC635_MODE_EXT1PPS              0x02
#define BC635_MODE_RTC                  0x03
#define BC635_MODE_GPS                  0x06

/* Periodic output sync mode */

#define BC635_SYNC_PPS                  0x01
#define BC635_NO_SYNC_PPS               0x00

/* Error returns */

#define BC635_FREQUENCY_RANGE_ERROR 3   /* exact divisor cannot be found. */
#define BC635_DIVISOR_ERROR         2   /* exact divisor cannot be found. */
#define BC635_DEVCTL_ERROR          1   /* devctl() is unsuccessful */
#define BC635_SUCCESS               0   /* call is successful. */

extern int      bc635_set_periodic_output(int fd, unsigned int period_microseconds, int one_pps_sync);
extern int      bc635_enable_int(int fd);
extern int      bc635_disable_int(int fd);
extern int      bc635_delay(int fd, unsigned int count);

extern int      bc635_set_mode(int fd, int seconds);
extern int      bc635_set_time(int fd, int seconds);


extern int      bc635_get_time(int fd, double *seconds, int *lockstatus);
extern int      bc635_get_model(int fd, char *model, int len);
extern int      bc635_get_assembly(int fd, char *assembly, int len);
extern int      bc635_get_hwfab(int fd, char *hwfab, int len);
extern int      bc635_get_firmware_part(int fd, char *firmware_part, int len);
extern int      bc635_get_serial(int fd, char *serial, int len);

extern void     bc635_lockstatus_str(int lockstatus, char *str);
extern int      bc635_software_reset(int fd);

#endif				/* // __BC635_H__ */
