/*
 *      Cover functions to simply get time from bc635pci
 *      time code processor.
 */

/*
 * DISCLAIMER:
 *
 *   THIS SOFTWARE IS SUPPLIED AS-IS BY THE JOHNS HOPKINS UNIVERSITY/APPLIED PHYSICS
 *   LABORATORY (JHU/APL).
 *
 *   WITH RESPECT TO THE INFORMATION, CODE AND/OR EXECUTABLES PROVIDED HEREIN,
 *   JHU/APL MAKES NO WARRANTIES OF ANY KIND, EITHER EXPRESSED OR IMPLIED,
 *   INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 *   FITNESS FOR A PARTICULAR PURPOSE. IN ADDITION, IN NO EVENT SHALL JHU/APL
 *   BE HELD LIABLE FOR ANY DAMAGES WHATSOEVER INCLUDING DIRECT, INDIRECT, INCIDENTAL,
 *   CONSEQUENTIAL, LOSS OF BUSINESS PROFITS OR SPECIAL DAMAGES, EVEN IF
 *   JHU/APL HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*/

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <errno.h>
#include <stdio.h>
#include <pthread.h>

#include "/home/jhz/sandbox/jhz/drivers/bc635pci/bc635.h"

static pthread_mutex_t guard = PTHREAD_MUTEX_INITIALIZER;

static int bc635_fd = -1;

static double tfirst = 0.0;

/* Some sort of exception handler must exist. */

static void default_exception( int en )
{
	printf("Exception handler not installed. Must call bc635_open_s() before other calls. Exiting.\n");
	exit(1);
}

/* Ponter to exception handler. */

static void (*except)( int en ) = default_exception;

/* cardname is like "/dev/bc635pci" */

int bc635_open_s( char *cardname, void (*f)( int en ))
{
	except = f;

	pthread_mutex_lock( &guard );
	if ( bc635_fd == -1 ) {
		bc635_fd = open( cardname,  O_RDONLY);
		if ( bc635_fd == -1 ) {
			except( 1 );
		}
	}
	pthread_mutex_unlock( &guard );
	return (0);
}

double bc635_get_time_s( void ) {
	double t;
	int lock;

	pthread_mutex_lock( &guard );
	if ( bc635_fd == -1 ) {
		except( 1 );
		pthread_mutex_unlock( &guard );
		return ( 0.0 );
	} else {
		bc635_get_time( bc635_fd, &t, &lock);
		pthread_mutex_unlock( &guard );
		return ( t );
	}
}

void bc635_timestamp_s( char *label )
{
	double tstamp;
	int lock;

	printf("%50s: %12.6f\n", label, bc635_get_time_s() - tfirst);
}

void bc635_set_first_time_s( double t )
{
	if ( t < 0.0 ) 
		except( 2 );
	else
		tfirst = t;
}
