
/*
 * DISCLAIMER:
 *
 *   THIS SOFTWARE IS SUPPLIED AS-IS BY THE JOHNS HOPKINS UNIVERSITY/APPLIED PHYSICS
 *   LABORATORY (JHU/APL).
 *
 *   WITH RESPECT TO THE INFORMATION, CODE AND/OR EXECUTABLES PROVIDED HEREIN,
 *   JHU/APL MAKES NO WARRANTIES OF ANY KIND, EITHER EXPRESSED OR IMPLIED,
 *   INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 *   FITNESS FOR A PARTICULAR PURPOSE. IN ADDITION, IN NO EVENT SHALL JHU/APL
 *   BE HELD LIABLE FOR ANY DAMAGES WHATSOEVER INCLUDING DIRECT, INDIRECT, INCIDENTAL,
 *   CONSEQUENTIAL, LOSS OF BUSINESS PROFITS OR SPECIAL DAMAGES, EVEN IF
 *   JHU/APL HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*/

#ifndef __BC635DVR_H__
#define __BC635DVR_H__

/* Structure to return time and lock status in from devctl() call. */

typedef struct {
	double          seconds;
	int             lockstatus;
}               time_struct_t;

/* Structure to pass divisors and 1 PPS sync to BC635_SET_PERIODIC_OUTPUT */

typedef struct {
	uint16_t        divisors[2];
	int             one_pps_sync;
}               divisors_t;

/*
 * Define command argument in devctl() to bc635pci driver.
 *
 * See devctl() man page for discussion. Basically, these macros create an int
 * with information packed into it to use as the command argument (dcmd) to the
 * devctl() function.
 *
 * The info includes:
 *
 *    1. direction of data (name of macro: __DIOT to device or __DIOF from device)
 *    2. command class (First arg to macro: _DCMD_MISC)
 *    3. the command value (Second argument to macro)
 *    4. type of data (Third argument to macro)
 */

/* Interrupt-related things */

#define BC635_SET_PERIODIC_OUTPUT (__DIOT( _DCMD_MISC, 1, divisors_t))
#define BC635_ENABLE_INT (__DION( _DCMD_MISC, 2))
#define BC635_DISABLE_INT (__DION( _DCMD_MISC, 3))
#define BC635_SOFTWARE_RESET (__DION( _DCMD_MISC, 11))

/* Set things */

#define BC635_SET_MODE (__DIOT( _DCMD_MISC, 5, unsigned int))
#define BC635_SET_TIME (__DIOT( _DCMD_MISC, 6, unsigned int))

/* Delay n tics. */

#define BC635_DELAY    (__DIOT( _DCMD_MISC, 12, unsigned int))

/* Get things */

#define BC635_GET_TIME (__DIOF( _DCMD_MISC, 7, double))
#define BC635_GET_MODEL (__DIOF( _DCMD_MISC, 8, char))
#define BC635_GET_ASSEMBLY (__DIOF( _DCMD_MISC, 13, char))
#define BC635_GET_HWFAB (__DIOF( _DCMD_MISC, 14, char))
#define BC635_GET_FIRMWARE_PART (__DIOF( _DCMD_MISC, 9, char))
#define BC635_GET_SERIAL (__DIOF( _DCMD_MISC, 10, char))

#endif				/* __BC635DVR_H__ */
