/*
 *      test1 - Test bc635pci driver with second non-control process.
 */

/*
 * DISCLAIMER:
 *
 *   THIS SOFTWARE IS SUPPLIED AS-IS BY THE JOHNS HOPKINS UNIVERSITY/APPLIED PHYSICS
 *   LABORATORY (JHU/APL).
 *
 *   WITH RESPECT TO THE INFORMATION, CODE AND/OR EXECUTABLES PROVIDED HEREIN,
 *   JHU/APL MAKES NO WARRANTIES OF ANY KIND, EITHER EXPRESSED OR IMPLIED,
 *   INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 *   FITNESS FOR A PARTICULAR PURPOSE. IN ADDITION, IN NO EVENT SHALL JHU/APL
 *   BE HELD LIABLE FOR ANY DAMAGES WHATSOEVER INCLUDING DIRECT, INDIRECT, INCIDENTAL,
 *   CONSEQUENTIAL, LOSS OF BUSINESS PROFITS OR SPECIAL DAMAGES, EVEN IF
 *   JHU/APL HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*/

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <fcntl.h>
#include <errno.h>
#include <sys/ioctl.h>
#include <devctl.h>
#include <math.h>
#include <pthread.h>

#include "bc635.h"

/* Thread function */

static void *periodic( void *argv );
static int bc635_fd;

int
main(int argc, char *argv)
{
	int             i;
	int             nbytes;
	int             lockstatus;
	double          dtime1;
	double          dtime2;
	double          deltasec;
	double          seconds = 100.0;
	u_int           info;
	char            str[100];

	printf("test1: bc635pci non-control test process.\n");

	/* Open the bancomm bc635pci card. */

	bc635_fd = open("/dev/bc635pci", O_RDONLY);
	if (-1 == bc635_fd) {
		perror("open(\"/dev/bc635pci\"): ");
		exit(1);
	}
	/* Get and print time value */

	if (bc635_get_time(bc635_fd, &dtime1, &lockstatus))
		perror("bc635_gettime(): ");

	printf("Time is now : %12.6f\n", dtime1);

	/* Assume another process has started periodic
	 * outputs (and interrupts.
	 */

	/* Start threads to wait for tics */

	pthread_create( NULL, NULL, periodic, (void *)1);
	pthread_create( NULL, NULL, periodic, (void *)2);
	pthread_create( NULL, NULL, periodic, (void *)3);
	pthread_create( NULL, NULL, periodic, (void *)4);


	sleep( 10 );

	while (1) {
		if (bc635_get_time(bc635_fd, &dtime1, &lockstatus))
			perror("bc635_gettime(): ");

		if (bc635_get_time(bc635_fd, &dtime2, &lockstatus))
			perror("bc635_gettime(): ");

		printf(" Times with  Zero delay: T1 = %12.6f T2 = %12.6f Delta = %12.6f\n",
		       dtime1, dtime2, dtime2 - dtime1);
		sleep(1);
	}

}

/* 
 * Function to run as thread to wait for tics. 
 */

static void *periodic( void *argv )
{
	double dtime;
	int lockstatus;
	int rtn;

	while (1) {
		rtn = bc635_delay(bc635_fd, 1);

		if ( 0 != rtn ) {
			printf("Interrupts off! Thread %d exiting.\n", (int)argv);
			fflush(0);
			pthread_exit(NULL);
		}
		if (bc635_get_time(bc635_fd, &dtime, &lockstatus))
			exit(1);

		printf("Thread %3d: %12.6f rtn = %d\n", (int)argv, dtime, rtn);
	}
}
		
