/*
 *      Simple test for errno thread safety.
 */

/*
 * DISCLAIMER:
 *
 *   THIS SOFTWARE IS SUPPLIED AS-IS BY THE JOHNS HOPKINS UNIVERSITY/APPLIED PHYSICS
 *   LABORATORY (JHU/APL).
 *
 *   WITH RESPECT TO THE INFORMATION, CODE AND/OR EXECUTABLES PROVIDED HEREIN,
 *   JHU/APL MAKES NO WARRANTIES OF ANY KIND, EITHER EXPRESSED OR IMPLIED,
 *   INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 *   FITNESS FOR A PARTICULAR PURPOSE. IN ADDITION, IN NO EVENT SHALL JHU/APL
 *   BE HELD LIABLE FOR ANY DAMAGES WHATSOEVER INCLUDING DIRECT, INDIRECT, INCIDENTAL,
 *   CONSEQUENTIAL, LOSS OF BUSINESS PROFITS OR SPECIAL DAMAGES, EVEN IF
 *   JHU/APL HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*/

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <errno.h>
#include <stdio.h>

#include "bc635_s.h"


static void *thread_fct( void *arg);
static double tfirst = 0.0;

/* bc635 exception handler */

static void *fex( int en ){
	printf("Exception from bc635 handler: %d\n", en);
	/* exit(1); */
}

int main( int argc, char **argv)
{
	int *val;
	pthread_t tid[2];
	int lock;

	/* Initialize static bc635 device and install exception handler */

	if ( -1 ==  bc635_open_s( "/dev/bc635pci", fex ) ){
		printf("Failed to initialize bc635pci.\n");
		exit (1);
	}
	bc635_set_first_time_s( bc635_get_time_s());

	/* Make sure /foo0 does not exist. */

	bc635_timestamp_s("Creating first thread");
	if ( EOK != pthread_create( &tid[ 0 ], NULL, thread_fct, (void *)"/foo0") )
		printf("pthread create failed.\n");

	/* Make sure /home/jhz/tmp exists */

	bc635_timestamp_s("Creating second thread");
	if ( EOK != pthread_create( &tid[ 1 ], NULL, thread_fct, (void *)"/home/jhz/tmp") )
		printf("pthread create failed.\n");

	bc635_timestamp_s("Joining thread 0");
	pthread_join(tid[ 0 ], &val);
	bc635_timestamp_s("Joining thread 1");
	pthread_join(tid[ 1 ], &val);
	bc635_timestamp_s("Joined both threads");
}

/* Function passed filename as argument when created as thread. */

static void *thread_fct( void *arg)
{
	int rtn;
	char str[ 100 ];

	sprintf(str, "Thread %d opening file %s", pthread_self(), (char *)arg);
	bc635_timestamp_s( str );

	rtn = open((char *)arg, O_RDONLY);
	if ( rtn == -1 ) {
		sprintf( str, "Thread %d open failed: %s", pthread_self(), strerror( errno ));
	} else {
		sprintf(str, "Thread %d open succeeded.", pthread_self());
	}
	bc635_timestamp_s( str );
}
	
