/*
 * NAME
 *
 *       phex() - Print bytes in buffer in hex to STDOUT.
 *       pciinfoshowhex() - Show the data in the struct pci_dev_info.
 *
 * AUTHOR
 *
 *      John H. Zouck
 *      The Johns Hopkins University
 *      Applied Physics Laboratory
 *      Johns Hopkins Rd.
 *      Laurel, MD 20723
 */

/*
 * DISCLAIMER:
 *
 *   THIS SOFTWARE IS SUPPLIED AS-IS BY THE JOHNS HOPKINS UNIVERSITY/APPLIED PHYSICS
 *   LABORATORY (JHU/APL).
 *
 *   WITH RESPECT TO THE INFORMATION, CODE AND/OR EXECUTABLES PROVIDED HEREIN,
 *   JHU/APL MAKES NO WARRANTIES OF ANY KIND, EITHER EXPRESSED OR IMPLIED,
 *   INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 *   FITNESS FOR A PARTICULAR PURPOSE. IN ADDITION, IN NO EVENT SHALL JHU/APL
 *   BE HELD LIABLE FOR ANY DAMAGES WHATSOEVER INCLUDING DIRECT, INDIRECT, INCIDENTAL,
 *   CONSEQUENTIAL, LOSS OF BUSINESS PROFITS OR SPECIAL DAMAGES, EVEN IF
 *   JHU/APL HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*/

#include <stdio.h>
#include <hw/pci.h>

/*
 *  phex() - Print bytes in buffer in hex to STDOUT.
 */

void
phex(char *buf, int n)
{
        int             i;

        for (i = 0; i < n; i++) {
                if (i != 0 && i % 16 == 0)
                        printf("\n");
                printf("%02x ", (unsigned char) buf[i]);
        }
        printf("\n");

}


/*
 * pciinfoshowhex(): Show the data in the struct pci_dev_info data 
 *                   structure in hex.
 */

void 
pciinfoshowhex(struct pci_dev_info *info)
{

        printf("struct pci_dev_info:\n");
        printf(
                "            DeviceId = 0x%04hx\n"
                "            VendorId = 0x%04hx\n"
                "         SubSystemId = 0x%04hx\n"
                "   SubSystemVendorId = 0x%04hx\n"
                "           BusNumber = 0x%02x\n"
                "            DevFunc  = 0x%02x\n"
                "            Revision = 0x%02x\n"
                "               Class = 0x%08x\n"
                "                 Irq = 0x%08x\n",
                info->DeviceId,
                info->VendorId,
                info->SubsystemId, info->SubsystemVendorId, info->BusNumber,
                info->DevFunc, info->Revision, info->Class, info->Irq
	);
}
